@@ -1,4 +1,4 @@
-:	"@(#)$Id: test.all.sh,v 1.8 1997/11/18 05:33:01 johnl Exp $"
+:	"@(#)$Id: test.all.sh,v 1.9 1998/08/06 01:52:48 jleffler Exp $"
 #
 #	Run tests against logged, unlogged and mode_ansi databases
 
@@ -10,7 +10,7 @@ do
 	echo
 	echo "Testing database $dbase"
 	if	DBD_INFORMIX_DATABASE=$dbase \
-		PERL_DL_NONLAZY=1 ${PERL:-/usr/bin/perl} \
+		PERL_DL_NONLAZY=1 ${PERL:-perl} \
 		-I./blib/arch \
 		-I./blib/lib \
 		-e 'use Test::Harness qw(&runtests $verbose);
